<?php

/**
 * @file
 * Provides the admin callback functionalities
 */

module_load_include('inc', 'beididp');

/**
 * Return the roles for a specified user.
 *
 * @param int $uid
 *   User ID.
 *
 * @return array
 *   Array of roles.
 */
function beididp_checkrole_get_roles($uid) {
  global $user;

  $roles = array();
  if ($uid == $user->uid) {
    $roles = $user->roles;
  }
  else {
    $check_user = user_load($uid);
    $roles = $check_user->roles;
  }
  return $roles;
}

/**
 * Get the roles that require eID for login.
 *
 * @return array
 *   Array of role IDs requiring eID.
 */
function beididp_checkrole_eid_roles() {
  return array_keys(variable_get('beididp_required_for_role', array()), 1);
}

/**
 * Checks if admin can bypass eID-only login. 
 *
 * @return bool 
 *   TRUE if admin can bypass
 */
function beididp_checkrole_admin_bypass() {
  return variable_get('beididp_checkrole_admin_bypass', TRUE);
}


/**
 * Checks if a user needs to have an eID linked to his account,
 * with current user roles or a given set of roles.
 *
 * @param int $uid
 *   User ID.
 * @param array $roles
 *   List of role IDs.
 *
 * @return 
 *   FALSE if the user does not need eID, or the list of eID-only roles.
 */
function beididp_checkrole_user_needs_eid($uid, $roles = array()) {
  if (empty($roles)) {
    $roles = array_keys(beididp_checkrole_get_roles($uid));
  }
  $eid_roles = beididp_checkrole_eid_roles();
  $block = array_intersect($roles, $eid_roles);

  if (empty($block)) {
    return FALSE;
  }
  return $block; 
}

